import { IKey } from '@aws-cdk/aws-kms';
import { ISecret, Secret } from '@aws-cdk/aws-secretsmanager';
import { Construct } from 'constructs';
/**
 * Construction properties for a DatabaseSecret.
 *
 * @stability stable
 */
export interface DatabaseSecretProps {
    /**
     * The username.
     *
     * @stability stable
     */
    readonly username: string;
    /**
     * The KMS key to use to encrypt the secret.
     *
     * @default default master key
     * @stability stable
     */
    readonly encryptionKey?: IKey;
    /**
     * The physical name of the secret.
     *
     * @default Secretsmanager will generate a physical name for the secret
     * @stability stable
     */
    readonly secretName?: string;
    /**
     * The master secret which will be used to rotate this secret.
     *
     * @default - no master secret information will be included
     * @stability stable
     */
    readonly masterSecret?: ISecret;
    /**
     * Characters to not include in the generated password.
     *
     * @default "\"
     * @stability stable
     * @ /"
     */
    readonly excludeCharacters?: string;
}
/**
 * A database secret.
 *
 * @stability stable
 * @resource AWS::SecretsManager::Secret
 */
export declare class DatabaseSecret extends Secret {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: DatabaseSecretProps);
}
